itam: Innovative Trend Analysis Method

View source: R/itam.R

itamR Documentation

Innovative Trend Analysis Method

Description

The function performs the innovative trend analysis method (Şen 2012).

Usage

itam(x, conf.level = 0.95)

Arguments

x

numeric vector or a time series object of class "ts"

conf.level

numeric, the level of significance

Details

The magnitude of trend is calculated based on the difference between the arithmeric means of the second half \bar{y} and the first half \bar{x} of the time series:

b = 2 ~ \left( \bar{y} - \bar{x} \right) / n,

with n the total number of observations in the full series.

The corresponding standard deviation is

\sigma_{b} = \frac{2 ~ \sqrt(2)}{n \sqrt(n)} s \sqrt(1 - \rho_{xy}),

with s the standard deviation of the full series and \rho_{xy} the correlation coeffientient between the orderer first half (X) and the ordered second half (Y) sub-series.

The test statistitic is:

z = b / \sigma_{b}.

The p-values are calculated from the standard normal distribution for the two-sided case.

Value

A list of class “htest” and “itam”.

estimates

numeric, ITAM slope

data.name

character string that denotes the input data

p.value

the p-value

statistic

the z quantile of the standard normal distribution

null.value

the null hypothesis

conf.in

upper and lower confidence limit

alternative

the alternative hypothesis

method

character string that denotes the test

df

A data.frame with ordered x1 and ordered x2

Note

Current Version is for complete observations only. For odd n the mid-point of the series is omitted.

References

Şen, Z. (2012) Innovative Trend Analysis Methodology. Journal of Hydrologic Engineering 17, 1042–1046. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1061/(ASCE)HE.1943-5584.0000556")}

Examples

(out <- itam(Nile))
plot(out)


trend documentation built on Sept. 3, 2026, 5:09 p.m.